@@ -32,12 +32,10 @@ class State(object):
     """
     STATE_NAME_RE = re.compile('\w+$')
 
-    def __init__(self, name, title=None):
+    def __init__(self, name, title):
         if not self.STATE_NAME_RE.match(name):
             raise ValueError('Invalid state name %s.' % name)
         self.name = name
-        if not title:
-            title = name
         self.title = title
 
     def __repr__(self):
